#!/usr/bin/python2.2

## soundcard.py - Contains the UI code needed for redhat-config-soundcard
## Copyright (C) 2002 Red Hat, Inc.
## Copyright (C) 2002 Brent Fox <bfox@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import string
import gtk
import gobject
import string
import sys
sys.path.append('/usr/share/redhat-config-soundcard/')
import soundcardBackend

##
## I18N
## 
from rhpl.translate import _, N_
import rhpl.translate as translate
translate.textdomain ("redhat-config-soundcard")

##
## Icon for windows
##

iconPixbuf = None      
try:
    iconPixbuf = gtk.gdk.pixbuf_new_from_file("/usr/share/redhat-config-soundcard/pixmaps/multimedia.png")
except:
    pass

class childWindow:
    #You must specify a runPriority for the order in which you wish your module to run
    runPriority = 64
    moduleName = _("Soundcard Detection")
    commentTag = _("Auto-detect and configure soundcard")

    def destroy(self, args):
        gtk.mainquit()
    
    def __init__(self, doDebug=None, backend=None):
        self.doDebug = doDebug

        self.default_card = ""
        if backend == None:
            self.soundcardBackend = soundcardBackend.soundcardBackend()
        else:
            self.soundcardBackend = backend
        self.card_list = self.soundcardBackend.probeCards()

        if self.doDebug:
            print "Kudzu detected %d cards" % len(self.card_list)

        self.toplevel = gtk.VBox()
        self.icon_box = gtk.HBox()
        self.title = gtk.Label(_("Sound Card Selection"))
        self.title.modify_fg(gtk.STATE_NORMAL, gtk.gdk.color_parse ("white"))

        self.notebook = gtk.Notebook()
        if len(self.card_list) < 2:
            self.notebook.set_show_tabs(gtk.FALSE)
#            self.notebook.set_show_border(gtk.FALSE)

        if self.card_list == []:
            #There are no cards available
            self.warning_label = gtk.Label(_("No soundcards were detected."))
            label = gtk.Label("")
            self.notebook.append_page(self.warning_label, label)
            
        else:
            #Kudzu has found some cards
            for card in self.card_list:
                self.device, self.module, self.maker, self.model = self.soundcardBackend.getData(card)
                self.default_card = self.model

                self.table = gtk.Table(2, 3)
                self.table.set_border_width(6)
                self.table.set_col_spacings(4)
                self.table.set_row_spacings(4)
    #            maker, model = string.split(self.description, "|")

                label = gtk.Label(_(" %s" % (self.maker)))

                self.notebook.append_page(self.table, label)
                self.maker_label = gtk.Label(_("Vendor:"))
                self.maker_label.set_alignment(0.0, 0.5)
                self.maker_label2 = gtk.Label(self.maker)
                self.maker_label2.set_alignment(0.0, 0.5)

                self.model_label = gtk.Label(_("Model:"))
                self.model_label.set_alignment(0.0, 0.5)

                self.model_label2 = gtk.Label(self.model)
                self.model_label2.set_alignment(0.0, 0.5)

                self.module_label = gtk.Label(_("Module:"))
                self.module_label.set_alignment(0.0, 0.5)

                self.module_label2 = gtk.Label(_(self.module))
                self.module_label2.set_alignment(0.0, 0.5)

                self.test_button = gtk.Button(_("Play test sound"))
                self.test_button.connect("clicked", self.playTestSound)

                align = gtk.Alignment(1.0, 0.5)
                align.add(self.test_button)

                self.table.attach(self.maker_label, 0, 1, 0, 1, gtk.FILL, gtk.FILL)
                self.table.attach(self.maker_label2, 1, 2, 0, 1, gtk.FILL, gtk.FILL)
                self.table.attach(self.model_label, 0, 1, 1, 2, gtk.FILL, gtk.FILL)
                self.table.attach(self.model_label2, 1, 2, 1, 2, gtk.FILL, gtk.FILL)
                self.table.attach(self.module_label, 0, 1, 2, 3, gtk.FILL, gtk.FILL)
                self.table.attach(self.module_label2, 1, 2, 2, 3, gtk.FILL, gtk.FILL)
                self.table.attach(align, 1, 2, 3, 4)

        #Add icon to the top frame
        p = None
        try:
            p = gtk.gdk.pixbuf_new_from_file("../pixmaps/multimedia.png")
        except:
            try:
                p = gtk.gdk.pixbuf_new_from_file("/usr/share/redhat-config-soundcard/pixmaps/multimedia.png")
            except:
                pass

        if p:
            self.icon = gtk.Image()
            self.icon.set_from_pixbuf(p)

    def okClicked(self, *args):
        self.apply()
        gtk.mainquit()

    def apply(self, *args):
        if self.doDebug:
            return

        try:
            #Do this in a try, because we might have no soundcards at all
            device, module, maker, model = self.soundcardBackend.getData(self.card_list[0])
            self.default_card = model
        except:
            pass

        self.mainWindow.destroy()

    def playTestSound(self, *args):
        self.soundcardBackend.playTestSound()
        pass

    def getNotebook(self):
        return self.notebook

    def launch(self):
        self.mainVBox = gtk.VBox()
        self.internalVBox = gtk.VBox(gtk.FALSE, 10)
        self.internalVBox.set_border_width(10)

        eventBox = gtk.EventBox()
        eventBox.add(self.icon_box)
        eventBox.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse ("#cc0000"))

        self.icon_box.pack_start(self.icon, gtk.FALSE, gtk.TRUE)        
        self.icon_box.pack_start(self.title)
        self.mainVBox.pack_start(eventBox, gtk.FALSE)
        self.msg_label.set_size_request(500, -1)
        self.internalVBox.pack_start(self.msg_label, gtk.FALSE)
        self.mainVBox.pack_start(self.internalVBox, gtk.TRUE)
        return self.mainVBox, eventBox

    def stand_alone(self):
        self.mainWindow = gtk.Dialog()
        self.mainWindow.vbox.set_spacing(5)
        self.mainWindow.connect("destroy", self.destroy)
        self.mainWindow.set_title(_("Sound Card Configuration"))
        self.mainWindow.set_border_width(10)
        self.mainWindow.set_position(gtk.WIN_POS_CENTER)
        self.mainWindow.set_icon(iconPixbuf)
        self.okButton = self.mainWindow.add_button('gtk-ok', 0)
        self.okButton.connect("clicked", self.okClicked)

        self.toplevel.set_spacing(5)
        self.icon_box.pack_start(self.icon, gtk.FALSE)
        self.icon_box.pack_start(self.notebook, gtk.FALSE)
        self.toplevel.pack_start(self.icon_box, gtk.FALSE)

        #Remove the hsep from the dialog.  It's ugly
        hsep = self.mainWindow.get_children()[0].get_children()[0]
        self.mainWindow.get_children()[0].remove(hsep)
        self.mainWindow.vbox.pack_start(self.toplevel)
        self.mainWindow.show_all()
        gtk.mainloop()

    #The getData function can return the name of the setting being changed
    #This is useful for the hardware screen in firstboot
    def getData(self):
        return self.default_card
        
